@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 from cms.apphook_pool import apphook_pool
-from cms.exceptions import NoHomeFound
 from cms.utils.moderator import get_page_queryset
 
 from django.conf import settings
@@ -9,6 +8,7 @@ from django.contrib.sites.models import Site
 from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import RegexURLResolver, Resolver404, reverse, \
     RegexURLPattern
+from django.db.models import Q
 from django.utils.importlib import import_module
 
 APP_RESOLVERS = []
@@ -32,7 +32,10 @@ def applications_page_check(request, current_page=None, path=None):
         try:
             page_id = resolver.resolve_page_id(path)
             # yes, it is application page
-            page = get_page_queryset(request).get(id=page_id)
+            if settings.CMS_MODERATOR:
+                page = get_page_queryset(request).get(Q(id=page_id) | Q(publisher_draft=page_id))
+            else:
+                page = get_page_queryset(request).get(id=page_id)
             # If current page was matched, then we have some override for content
             # from cms, but keep current page. Otherwise return page to which was application assigned.
             return page
@@ -124,7 +127,7 @@ def get_patterns_for_title(path, title):
     app = apphook_pool.get_apphook(title.application_urls)
     patterns = []
     for pattern_list in get_app_urls(app.urls):
-        if not path.endswith('/'):
+        if path and not path.endswith('/'):
             path += '/'
         page_id = title.page.id
         patterns += recurse_patterns(path, pattern_list, page_id)
