@@ -1,13 +1,17 @@
-from django.forms.models import ModelForm
-from django.utils.translation import ugettext_lazy as _
-from cms.plugins.link.models import Link
-from django import forms
 from cms.models import Page
+from cms.plugins.inherit.models import InheritPagePlaceholder
+from django import forms
+from django.forms.models import ModelForm
 from django.forms.util import ErrorList
+from django.utils.translation import ugettext_lazy as _
 
 class InheritForm(ModelForm):
     from_page = forms.ModelChoiceField(label=_("page"), queryset=Page.objects.drafts(), required=False)
     
+    class Meta:
+        model = InheritPagePlaceholder
+        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')
+    
     def for_site(self, site):    
         # override the page_link fields queryset to containt just pages for
         # current site
@@ -17,8 +21,4 @@ class InheritForm(ModelForm):
         cleaned_data = super(InheritForm, self).clean()
         if not cleaned_data['from_page'] and not cleaned_data['from_language']:
             self._errors['from_page'] = ErrorList([_("Language or Page must be filled out")])
-        return cleaned_data
-    
-    class Meta:
-        model = Link
-        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')
\ No newline at end of file
+        return cleaned_data
\ No newline at end of file
